#
# spec file for package avidemux3
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           avidemux3
Summary:        Graphical video editing and transcoding tool
License:        GPL-2.0-only
Version:        2.8.1
Release:        1699.5.pm.3
URL:            http://avidemux.sourceforge.net/
ExclusiveArch:  %ix86 x86_64
Source0:        https://github.com/mean00/avidemux2/releases/download/%{version}/avidemux_%{version}.tar.gz
Patch0:         %name.patch
Patch1:         avidemux-linking.patch
Patch2:         avidemux-x264_plugins.patch
Patch3:         avidemux-x265_plugins.patch
Patch4:         avidemux-package_version.patch
Patch5:         avidemux-bootStrap.patch
Patch7:         avidemux-desktop-file.patch
Patch8:         avidemux-backport_Fix_threads_setup.patch
Patch9:         avidemux-ivtcDupeRemover-return-true-from-ivtcDupeRemover-get.patch
Patch10:        avidemux-translations.patch

# Utilities / Libraries
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  intltool
BuildRequires:  pkg-config
BuildRequires:  yasm
BuildRequires:  pkgconfig(vapoursynth)
BuildRequires:  pkgconfig(vapoursynth-script)
BuildRequires:  pkgconfig(ffnvcodec) > 8
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(xmu)

# Sound out
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libpulse)

# Video out
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(vdpau)
BuildRequires:  pkgconfig(xv)

# Audio Codecs
BuildRequires:  libaften-devel
BuildRequires:  libfaac-devel
BuildRequires:  libfaad-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  pkgconfig(dcaenc)
BuildRequires:  pkgconfig(fdk-aac)
BuildRequires:  pkgconfig(liba52)
BuildRequires:  pkgconfig(libdca)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opencore-amrnb)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(twolame)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vpx)

# Video Codecs
BuildRequires:  libxvidcore-devel
BuildRequires:  pkgconfig(aom)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(x264)
BuildRequires:  pkgconfig(x265)

# GUI
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5Script)
BuildRequires:  cmake(Qt5Widgets)

# Main package requires at least one frontend (cli or qt5)
Requires:       avidemux3-frontend = %{version}-%{release}

%description
Avidemux is a free video editor designed for simple cutting, filtering and
encoding tasks. It supports many file types, including AVI, DVD compatible
MPEG files, MP4 and ASF, using a variety of codecs. Tasks can be automated
using projects, job queue and powerful scripting capabilities.

Avidemux is available for Linux, BSD, Mac OS X and Microsoft Windows under
the GNU GPL license. The program was written from scratch by Mean, but code
from other people and projects has been used as well. Patches, translations
and even bug reports are always welcome.

%package cli
Summary:        CLI for avidemux
Group:          Productivity/Multimedia/Video/Editors and Convertors
Provides:       avidemux3-frontend = %{version}-%{release}
Requires:       avidemux3 = %{version}-%{release}

%description cli
Avidemux is a free video editor designed for simple cutting, filtering and
encoding tasks. It supports many file types, including AVI, DVD compatible
MPEG files, MP4 and ASF, using a variety of codecs. Tasks can be automated
using projects, job queue and powerful scripting capabilities.

Avidemux is available for Linux, BSD, Mac OS X and Microsoft Windows under
the GNU GPL license. The program was written from scratch by Mean, but code
from other people and projects has been used as well. Patches, translations
and even bug reports are always welcome.

This package provides a command-line interface to editing videos with avidemux.

%package qt5
Summary:        Qt interface for avidemux
Group:          Productivity/Multimedia/Video/Editors and Convertors
Provides:       avidemux3-frontend = %{version}-%{release}
Requires:       avidemux3 = %{version}-%{release}
Recommends:     avidemux3-qt5-lang = %{version}-%{release}

%description qt5
Avidemux is a free video editor designed for simple cutting, filtering and
encoding tasks. It supports many file types, including AVI, DVD compatible
MPEG files, MP4 and ASF, using a variety of codecs. Tasks can be automated
using projects, job queue and powerful scripting capabilities.

Avidemux is available for Linux, BSD, Mac OS X and Microsoft Windows under
the GNU GPL license. The program was written from scratch by Mean, but code
from other people and projects has been used as well. Patches, translations
and even bug reports are always welcome.

This package contains the Qt graphical interface for avidemux.

%package qt5-lang
Summary:        Languages for package avidemux3-qt5
Group:          System/Localization
Requires:       avidemux3-qt5 = %{version}-%{release}
BuildArch:      noarch

%description qt5-lang
Avidemux is a free video editor designed for simple cutting, filtering and
encoding tasks. It supports many file types, including AVI, DVD compatible
MPEG files, MP4 and ASF, using a variety of codecs. Tasks can be automated
using projects, job queue and powerful scripting capabilities.

Avidemux is available for Linux, BSD, Mac OS X and Microsoft Windows under
the GNU GPL license. The program was written from scratch by Mean, but code
from other people and projects has been used as well. Patches, translations
and even bug reports are always welcome.

This package provides translations for package avidemux3-qt5.

%prep
%autosetup -p1 -n avidemux_%{version}

%build
chmod 755 bootStrap.bash
chmod 644 AUTHORS COPYING README
flags+="%optflags -fno-strict-aliasing "
%ifarch %ix86
flags+="%optflags -march=native "
%endif
export CXXFLAGS="$flags"

options+="--with-cli "
./bootStrap.bash $options

%install
cp -r install/* %{buildroot}

# Install man
install -D -m644 man/avidemux.1 %{buildroot}%{_mandir}/man1/avidemux.1
rm -f %{buildroot}%{_datadir}/avidemux3/qt5/translations/qtbase_*.qm

# delete devel file (only needed for build)
rm -rf %{buildroot}%{_includedir}

%find_lang avidemux %{name}-qt5.lang --with-qt

%fdupes %buildroot

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post cli -p /sbin/ldconfig

%postun cli -p /sbin/ldconfig

%post qt5 -p /sbin/ldconfig 

%postun qt5 -p /sbin/ldconfig

%files
%{_bindir}/vsProxy
%{_libdir}/libADM6avcodec.so.*
%{_libdir}/libADM6avformat.so.*
%{_libdir}/libADM6avutil.so.*
%{_libdir}/libADM6postproc.so.*
%{_libdir}/libADM6swscale.so.*
%{_libdir}/libADM_audioParser6.so
%{_libdir}/libADM_core6.so
%{_libdir}/libADM_coreAudio6.so
%{_libdir}/libADM_coreAudioDevice6.so
%{_libdir}/libADM_coreAudioEncoder6.so
%{_libdir}/libADM_coreAudioFilterAPI6.so
%{_libdir}/libADM_coreDemuxer6.so
%{_libdir}/libADM_coreDemuxerMpeg6.so
%{_libdir}/libADM_coreImage6.so
%{_libdir}/libADM_coreImageLoader6.so
%{_libdir}/libADM_coreJobs.so
%{_libdir}/libADM_coreLibVA6.so
%{_libdir}/libADM_coreLibVAEnc6.so
%{_libdir}/libADM_coreMuxer6.so
%{_libdir}/libADM_coreScript.so
%{_libdir}/libADM_coreSocket6.so
%{_libdir}/libADM_coreSqlLight3.so
%{_libdir}/libADM_coreSubtitles6.so
%{_libdir}/libADM_coreUI6.so
%{_libdir}/libADM_coreUtils6.so
%{_libdir}/libADM_coreVDPAU6.so
%{_libdir}/libADM_coreVideoCodec6.so
%{_libdir}/libADM_coreVideoEncoder6.so
%{_libdir}/libADM_coreVideoFilter6.so
%dir %{_libdir}/ADM_plugins6
%dir %{_libdir}/ADM_plugins6/audioDecoder
%dir %{_libdir}/ADM_plugins6/audioDevices
%dir %{_libdir}/ADM_plugins6/audioEncoders
%dir %{_libdir}/ADM_plugins6/autoScripts
%dir %{_libdir}/ADM_plugins6/autoScripts/lib
%dir %{_libdir}/ADM_plugins6/demuxers
%dir %{_libdir}/ADM_plugins6/muxers
%dir %{_libdir}/ADM_plugins6/pluginSettings
%dir %{_libdir}/ADM_plugins6/pluginSettings/x264
%dir %{_libdir}/ADM_plugins6/pluginSettings/x264/3
%dir %{_libdir}/ADM_plugins6/scriptEngines
%dir %{_libdir}/ADM_plugins6/videoEncoders
%dir %{_libdir}/ADM_plugins6/videoFilters
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_a52.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_alaw.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_dca.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_faad.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_ima_adpcm.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_lav.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_Mad.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_ms_adpcm.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_opencore_amrnb.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_opencore_amrwb.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_opus.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_ulaw.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_vorbis.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_alsaDefault.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_alsaDMix.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_alsaHw.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_jack.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_oss.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_pulseAudio.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_aften.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_dcaenc.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_faac.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_fdk_aac.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_lame.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_lav_aac.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_lav_ac3.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_lav_mp2.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_opus.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_pcm.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_twolame.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_vorbis.so
%{_libdir}/ADM_plugins6/autoScripts/720p.py
%{_libdir}/ADM_plugins6/autoScripts/check24fps.py
%{_libdir}/ADM_plugins6/autoScripts/dvd.py
%{_libdir}/ADM_plugins6/autoScripts/lib/ADM_image.py
%{_libdir}/ADM_plugins6/autoScripts/lib/ADM_imageInfo.py
%{_libdir}/ADM_plugins6/autoScripts/PSP.py
%{_libdir}/ADM_plugins6/autoScripts/svcd.py
%{_libdir}/ADM_plugins6/autoScripts/vcd.py
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_asf.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_avsproxy.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_flv.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_matroska.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_mp4.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_mxf.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_opendml.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_pic.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_ps.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_ts.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_vapoursynth.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_avi.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_dummy.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_ffPS.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_ffTS.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_flv.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_mkv.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_mov.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_mp4.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_mp4v2.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_raw.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_webm.so
%{_libdir}/ADM_plugins6/pluginSettings/x264/3/fast.json
%{_libdir}/ADM_plugins6/pluginSettings/x264/3/iPhone.json
%{_libdir}/ADM_plugins6/pluginSettings/x264/3/Mezzanine.json
%{_libdir}/ADM_plugins6/pluginSettings/x264/3/PSP.json
%{_libdir}/ADM_plugins6/pluginSettings/x264/3/ultraFast.json
%{_libdir}/ADM_plugins6/pluginSettings/x264/3/veryFast.json
%{_libdir}/ADM_plugins6/scriptEngines/libADM_script_tinyPy.so
%dir %{_libdir}/ADM_plugins6/videoDecoders
%{_libdir}/ADM_plugins6/videoDecoders/libADM_vd_aom.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffDv.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffFlv1.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffMpeg2.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffMpeg4.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffNvencH264.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffNvencHEVC.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffVaEncH264.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffVaEncHEVC.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffv1.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_huff.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_jpeg.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_libva.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_null.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_utvideo.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_vp9.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_xvid4.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_yv12.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_aarotate.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_ascii.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_avsfilter.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_addBorders.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_admIvtc.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_black.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_blend.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_changeFps.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_colorYuv.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_decimateFrame.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_denoise3d.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_denoise3dhq.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_DgBob.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_dummy.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_fadeTo.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_fadeToBlack.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_FluxSmooth.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_gauss.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_hzstackField.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_ivtcDupeRemover.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_kernelDeint.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_largeMedian.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_lavDeint.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_lumaOnly.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_mean.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_median.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_mergeField.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_negative.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_printInfo.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_removePlane.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_resampleFps.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_rotate.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_ssa.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_separateField.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_sharpen.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_stackField.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_stillimage.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_swapUV.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_telecide.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_unstackField.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_vaapiFilter.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_vaapiFilterDeint.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_vdpauFilter.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_vdpauFilterDeint.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_yadif.so
%dir %{_datadir}/ADM6_addons
%dir %{_datadir}/ADM6_addons/avsfilter
%{_datadir}/ADM6_addons/avsfilter/avsload.exe
%{_datadir}/ADM6_addons/avsfilter/pipe_source.dll
%{_mandir}/man1/avidemux.1.gz
%doc AUTHORS README
%license COPYING

%files cli
%{_bindir}/avidemux3_cli
%{_libdir}/libADM_render6_cli.so
%{_libdir}/libADM_UI_Cli6.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_x264_cli.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_x265_cli.so
%dir %{_libdir}/ADM_plugins6/videoFilters/cli
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_analyzerCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_artCartoonCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_artCharcoalCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_artChromaHoldCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_artChromaKeyCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_artColorEffectCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_artDynThresholdCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_artGridCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_artMirrorCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_artPixelizeCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_artPosterizeCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_artVHSCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_artVignetteCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_blackenBordersCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_blurCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_chromaShiftCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_colorBalanceCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_colorTempCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_contrastCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_CropCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_cubicLUTCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_debandCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_delogoHQCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_eq2Cli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_fadeFromImageCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_fadeInCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_fadeOutCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_fadeThroughCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_fitToSizeCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_flipCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_HueCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_imageStabCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_logoCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_lumaStabCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_mpdelogoCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_msharpenCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_quadTransCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_swscaleResize_cli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_waveletDenoiseCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_waveletSharpCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_ZoomCli.so

%files qt5
%{_bindir}/avidemux3_jobs_qt5
%{_bindir}/avidemux3_qt5
%{_bindir}/vsProxy_gui_qt5
%{_libdir}/libADM_openGLQT56.so
%{_libdir}/libADM_render6_QT5.so
%{_libdir}/libADM_UIQT56.so
%dir %{_libdir}/ADM_plugins6/shaderDemo
%dir %{_libdir}/ADM_plugins6/shaderDemo/1
%dir %{_libdir}/ADM_plugins6/videoEncoders/qt5
%dir %{_libdir}/ADM_plugins6/videoFilters/qt5
%{_libdir}/ADM_plugins6/shaderDemo/1/bump.shader
%{_libdir}/ADM_plugins6/shaderDemo/1/lightning.shader
%{_libdir}/ADM_plugins6/shaderDemo/1/ripple.shader
%{_libdir}/ADM_plugins6/shaderDemo/1/zigzag.shader
%{_libdir}/ADM_plugins6/videoEncoders/qt5/libADM_ve_x264_QT5.so
%{_libdir}/ADM_plugins6/videoEncoders/qt5/libADM_ve_x265_QT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_analyzerQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_artCartoonQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_artCharcoalQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_artChromaHoldQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_artChromaKeyQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_artColorEffectQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_artDynThresholdQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_artGridQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_artMirrorQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_artPixelizeQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_artPosterizeQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_artVHSQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_artVignetteQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_asharpQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_blackenBordersQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_blurQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_chromaShiftQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_colorBalanceQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_colorTempQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_contrastQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_cropQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_cubicLUTQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_debandQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_delogoHQQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_eq2QT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_fadeFromImageQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_fadeInQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_fadeOutQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_fadeThroughQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_fitToSizeQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_flipQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_glBenchmark.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_glResize.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_HueQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_imageStabQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_lumaStabQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_logoQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_mpdelogoQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_msharpenQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_quadTransQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_rotateGlFrag2.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_sampleGlFrag2.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_sampleGlVertex.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_shaderLoaderGl.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_swscaleResizeQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_waveletDenoiseQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_waveletSharpQT5.so
%{_libdir}/ADM_plugins6/videoFilters/qt5/libADM_vf_zoomQT5.so
%{_datadir}/applications/org.avidemux.Avidemux.desktop
%{_datadir}/icons/hicolor/128x128/apps/org.avidemux.Avidemux.png
%{_datadir}/metainfo/org.avidemux.Avidemux.appdata.xml

%files qt5-lang -f %{name}-qt5.lang
%dir %{_datadir}/avidemux3
%dir %{_datadir}/avidemux3/qt5
%dir %{_datadir}/avidemux3/qt5/translations

%changelog
* Fri Feb  3 2023 enzokiel@kabelmail.de
- Update to version 2.8.1
  - New Features
  * New HiDPI compatible button set
  * Fast method to add partial filters via CTRL+F shortcut
  * Audio department improvements
    custom frame rate change (audio stretch with pitch control)
    configurable compressor (DRC)
    3-band equalizer
    independent channel gain options
    independent channel delay options
    channel remap options
    new downmix options: stereo headphone and headphone virtual
    surround
    audio track configuration up to 32 tracks
    volume setting is saved upon exit
  * Light and dark theme options in View menu
  * Option to remember selected resize method in "Resize",
    "Fit to size" and "Zoom" filters
  * New filter: 3D LUT
  * New filter: Decimate
  * New filter: Arbitrary Rotate
  * New video encoder: VideoToolbox HEVC ("ffVTEncHEVC",
    macOS only)
  - Other Enhancements
  * HDR tonemapping performance and quality improvements
  * Extended file info
  * Rotating mouse wheel over buttons to seek by 60 seconds
    cycles through 1/2/4/60 seconds seek modes
  * Support for decoding 8-bit VP9 in hardware via DXVA2 on
    Windows and via VDPAU on Linux with graphics cards featuring
    a VP9 decoder
  * Buttons to seek to selection start (A) and end (B) in
    on-the-fly video filter preview
  * Logo image in "Add logo" video filter configuration dialog is
    now scalable, can be repositioned by dragging
  * By default, on-the-fly preview in video filter configuration
    dialogs is now rendered using OpenGL to improve performance
    in HiDPI conditions
  - Bugfixes
  * Crash on copy to clipboard if selection extends to the end of
    video, a regression introduced in v2.8.0
  * Crashes in "Resample FPS" video filter with motion
    interpolation enabled
  * Crash on finishing encoding with the vp9 encoder
  * Avidemux falling victim to a crash in VA-API driver triggered
    by probing on application startup on Linux with some recent
    hardware
  * Crash loading MPEG-TS or MPEG-PS file with MPEG-1 video track
    and HW decoder via VDPAU enabled
  * Wrong number of channels or wrong channel layout with some
    E-AC3 streams
  * Reduced contrast and desaturated colors in loaded BMP images
  * Selection starting at zero and ending at the last picture of
    video cannot be deleted
  * Disabling B-frames breaks VideoToolbox HW encoder
    (macOS only)
  - Miscellaneous
  * Bundled FFmpeg libraries have been updated to 4.4.2 release.
  - Added options -march=native to enable build on i586.
* Mon Dec 27 2021 enzokiel@kabelmail.de
- Update to version 2.8.0
  - Behavior
  * The part of video preceding the presentation time of the first
    frame is now excluded from created segment, making all videos
    appear as if they "start at zero". When saving video, the frame
    matching the B marker is now excluded from the exported range.
    Therefore, if the B marker is set to the last frame of the
    video, it needs to be reset to the full duration for the last
    frame to be included into the output. Loading Matroska files
    with HEVC video tracks takes longer as slice headers are
    decoded to detect the frame type.
  - New Video Filters
  * Analyzer
  * Blur (on selected area)
  * Cartoon
  * Color balance (adjust shadow, midtone and highlight)
  * Chroma hold (monochrome effect with kept colors)
  * Chroma key (replace "green screen" with an image)
  * Deband (reduce banding artifacts)
  * DelogoHQ (clean up arbitrary shaped logo)
  * Dynamic threshold
  * Fade from first image
  * Fade in (combination of multiple effects)
  * Fade out (combination of multiple effects)
  * Fade through (combination of multiple effects)
  * Fit to size (resize and pad to the specified size)
  * Flip (vertically/horizontally flip the image)
  * Grid (video wall effect)
  * Image stabilizer (reduce camera shakiness)
  * Luma stabilizer (reduce flickering)
  * Mirror
  * Posterize
  * Quadrilateral transformation (four point transform)
  * Wavelet denoiser
  * Wavelet sharpener
  * Zoom (partializable crop filter)
  - New Features
  * HDR video can be converted to SDR with tone mapping using a
    variety of methods.
  * FFV1 encoder is back (it was available in Avidemux 2.5.x).
  * TrueHD audio tracks can be decoded and are supported for
    Matroska containers.
  * Decoding support for WMA9 Lossless codec.
  * Filter previews have got a unified method to quickly compare
    filtered and unfiltered inputs via the "Peek Original" button.
  * Blend and motion interpolation options added to "Resample FPS"
    filter.
  * Mark cut points (segment boundaries) on the navigation slider.
    New buttons and shortcuts are provided to jump to these cut
    points.
  * In the Video Filter Manager, active filters can be temporarily
    disabled.
  * Preference added to load sequentially named pictures in reverse
    order, allowing to reverse video by exporting selection as JPEG
    images and loading the first one.
  * During playback navigation is possible via keys or by dragging
    the navigation slider.
  - Other Enhancements
  * "Resample FPS" and "Change FPS" filters can handle up to 1000
    fps.
  * "Crop" filter's preview has got a translucent green masking.
  * "Crop" filter's Auto Crop function can achieve perfect crops
    (if the selected frame is not too dark).
  * The maximum output resolution of the "Resize" filter has been
    increased to 8192x8192
  * The "Resize" filter has got a nearest neighbour scaling option.
  * Improved HiDPI scaling in previews.
  * x264 video encoder plugin now allows to specify color properties.
  * Maximized window state, widget visibility and toolbar position
    are preserved after application restart.
  * Timestamps in format 00:00:00.000 like copied to clipboard by
    pressing CTRL+SHIFT+C can be pasted into the "Go to Time"
    dialog using CTRL+V.
  * PulseAudioSimple audio device has been replaced with full
    PulseAudio, making an in-application volume control available
    (Linux only).
  * ALSA audio device plugin has been modified to use soft volume,
    providing application-specific volume control which works with
    every ALSA device.
  * In the Video Filter Manager, navigation by keyboard has been
    enhanced.
  * The VU meter ("Audio Metre") has been redesigned.
  - Bugfixes
  * Occasional UI unrepsonsiveness during playback should be fixed.
  * Prevent navigation key events piling up.
  * Thumb slider, displaced by mouse wheel, is now automatically
    reset if the end of video is reached, stopping Avidemux log
    file from filling disk space.
  * Purple tint in old "Fade to" and "Fade to black" filters on
    macOS fixed.
  * Green tint in "MPlayer eq2" filter is fixed.
  - Miscellaneous
  * Bundled FFmpeg libraries have been updated to 4.4.1 release.
* Tue Mar  9 2021 enzokiel@kabelmail.de
- Update to version 2.7.8
  - New Features
  * Many new video filters added by courtesy of szlldm
  * A dedicated MOV muxer is now available, replacing silent
    fallback to MOV muxing mode within the MP4 muxer.
  * A subset of color info relevant for HDR support is retained
    in copy mode when both input and output video are stored in
    Matroska / WebM containers. Settings to add or override color
    info have been added to MKV and WebM muxers.
  * The indexer in the MPEG-TS demuxer now detects resolution
    changes in MPEG-2 and H.264 streams which are entirely
    unsupported and suggests aborting indexing. If the user
    chooses to continue, it records file offsets of all
    resolution changes to the log. This allows advanced users to
    split the file at these offsets using other tools like head
    and tail into chunks which can be processed with Avidemux.
  * YUV varieties of the lossless Ut Video codec are supported
    now for decoding and encoding via bundled FFmpeg libraries.
    Uncompressed 24-bit audio is now supported for a subset of
    file formats.
  * Limited support for 7.1 channel layout. Decode and stream
    copy support for XLL substream in DTS audio tracks.
  * Audio properties are now updated on resuming playback. This
    allows to start saving after an audio format change. When
    audio format changes during playback, the FFmpeg-based audio
    decoder will output silence and keep format rather than
    producing garbage.
  * An option to keep the identity of markers A and B instead of
    swapping them automatically has been added to Preferences.
  * The keyboard shortcut for "Delete" action has been made
    customizable with alternative keyboard shortcuts enabled.
  - Other Enhancements
  * Multi-threaded video decoding is now available for the
    bundled FFmpeg. On powerful multi-core CPUs, this can
    drastically improve decoding performance. A maximum of 8
    threads can be created, but a conservative custom upper limit
    of 4 is recommended. Values above 8 cause decoding failures.
    Multi-threaded decoding and HW accelerated decoding are
    mutually exclusive, changes require application restart to
    have effect.
  * The maximum supported resolution has been increased to
    8192x8192
  * The bundled FFmpeg has been updated to the 4.2.4 release.
  * Non-standard display aspect ratios can be configured in MP4
    muxer by specifying display width.
  * MP4 muxer accepts now MPEG-1 and MPEG-2.
  * The configuration dialog of the x265 video encoder plugin
    enjoyed massive cleanup and refactoring by Trent Piepho ,
    more Adaptive
  * Quantization Variance methods have been added.
  * Python interface has been substantially extended, includes
    now methods to query segment properties, the number and
    filenames of loaded videos, PTS of keyframes, methods to seek
    to time with preview updated, to open file dialogs filtered
    by extension and a built-in method to split filename
    extension from a given path.
  * Scripting shell now supports unicode characters.
  * On macOS, files can be loaded via Finder context menu or by
    dropping them onto Avidemux icon in the dock.
  * On Linux, Jobs GUI and the CLI executable can be launched
    from AppImage by creating a symlink with _jobs or _cli in
    filename respectively and running the AppImage via this
    symlink.
  - Bugfixes
  * Rate control was broken in some video encoders, especially in
    VP9 and in NVENC-based encoders, fixed now.
  * Multiple issues in cut point checks for H.264 and HEVC
    streams in copy mode, leading to incorrect check results,
    were identified and resolved.
  * The first two frames of external AC3 or EAC3 audio tracks are
    not dropped anymore. This regression from enhanced protection
    against false positives, added 3 years ago, has been finally
    identified and fixed.
  * Indexing of MPEG-TS files with HEVC video was broken when
    video stream lacked access unit delimiters. The issue was
    identified and fixed right after 2.7.7 had been tagged as
    released and is the reason why version 2.7.7 was superseded
    by 2.7.8.
  * VU meter was grossly ahead of audio output on Windows, now it
    is just a tiny little bit ahead.
  * Numerous other fixes and overall polish.
* Fri Feb 26 2021 enzokiel@kabelmail.de
- Build against ffnvcodec for Leap 15.2
* Wed Jul 29 2020 enzokiel@kabelmail.de
- Disabled build against ffnvcodec for Leap <= 15.2, build requires
  version > 8
* Wed Jul  8 2020 Fridrich Strba <fridrich.strba@bluewin.ch>
- Fix build by actually applying the
  avidemux-ivtcDupeRemover-return-true-from-ivtcDupeRemover-get.patch
* Tue Jul  7 2020 enzokiel@kabelmail.de
- Update to version 2.7.6
  + New Feature:Detect and warn when cut points in HEVC video
    streams may result in grave playback issues despite being on
    keyframes
  + New Video Decoder:Add libaom-based AV1 decoder
  + New Video Encoder:Add libvpx-based VP9 encoder
  + New Video Filter:Add hardware accelerated deinterlacer and
    resizer based on VA-API (Linux only)
  + FFmpeg:Update to the 4.2.3 release
  + Core:Increase maximum supported resolution to 4096x4096
  + Core:Fix crash on macOS with HW accel. decoding enabled and
    H.264 video streams containing both frame- and field-encoded
    slices
  + Encoder:Extend configuration options for NVENC-based H.264 and
    HEVC encoders, add 2-pass mode
  + Demuxer:Support MPEG-TS files with duration in excess of
    13:15:36
  + Demuxer:Use DTS core from DTS XLL audio in MPEG-TS files
    instead of rejecting the track
  + Demuxer:Fix mono MP3 audio tracks in MP4 files misdetected as
    stereo
  + Demuxer:Try to correct timestamp jitter in MP4 files produced
    by older Avidemux versions
  + Muxer:Fix timestamp rounding which caused pseudo-VFR output
    from CFR sources
  + Muxer:Fix saving to network shares on Windows using the Mp4
    muxer when index should be moved to the start of the file
  + Muxer:Support LPCM audio in the Mp4 muxer by silently
    switching to the MOV muxing mode
  + Muxer:Add support for Vorbis audio to the Mp4 muxer
  + Filter:Fix "Fade" and "Fade to black", broken on macOS
  + Filter:Allow to toggle rubber band visibility in "Crop" and
    "Blacken Borders" video filters
  + Filter:Fix keyboard input in "Resize" video filter by
    recalculating values only on moving focus to another field or
    on accepting dialog
  + Audio:Add HE-AAC and HE-AACv2 profiles to the FDK AAC encoder
    plugin
  + Audio:Support external audio tracks in DTS format
  + UI:Fix navigation slider with RTL locales
  + UI:Restore the shutdown option in encoding dialog on Windows
  + Scripting:Add PTS query and keyframe seek methods to Python
    interface
  + Miscellaneous:Allow user-defined fragment size for auto-append
    of chunked MPEG-TS files
  + Miscellaneous:Improve handling of field-encoded video streams
    throughout the chain
  + Miscellaneous:Improve handling of H.264 video streams with
    parameter sets changing on the fly
  + Miscellaneous:Try to keep track of video time base throughout
    the chain
  + Miscellaneous:Numerous other fixes and polish
- Removed avidemux-cpu-detection-fix.patch, fixed upstream.
* Tue Nov 12 2019 Jiri Slaby <jslaby@suse.cz>
- add avidemux-cpu-detection-fix.patch (build fix)
- add avidemux-ivtcDupeRemover-return-true-from-ivtcDupeRemover-get.patch
  (build fix)
* Sun Aug 18 2019 enzokiel@kabelmail.de
- Update to version 2.7.4
  + New Feature:Detect and warn when cut points in H.264 video
    streams may result in playback issues despite being on keyframes
  + FFmpeg:Update to the 4.1.4 release
  + Core:Fix MSVC++ builds do not run when the path to user
    directory contains non-ASCII characters
  + Decoder:Fix DXVA2 HW accelerated decoding on Windows 7
  + Decoder:Fix DXVA2 HW accelerated decoding stops sometimes on
    cuts
  + Decoder:Enable HW accelerated decoding of 8-bit HEVC for recent
    versions of Intel graphics driver on Windows
  + Encoder:Fix regression with saved x264 and x265 profiles not
    found (MSVC++ only)
  + Demuxer:Dynamically load VapourSynth Script library to avoid
    error messages on Windows if VapourSynth is not found
  + Demuxer:Provide correct average audio bitrate in the Mp4
    demuxer if the exact value for the particular codec is unknown
  + Demuxer:Fix crash loading MP4 file with number of audio tracks
    exceeding the max supported
  + Demuxer:Support audio tracks in fragmented MP4 files (the
    variety with empty moov only)
  + Demuxer:Support E-AC3 audio tracks in MP4 files
  + Demuxer:Fix ASF demuxer still broken by chance with MSVC++
    only, the fix relevant for all platforms
  + Demuxer:Support more varieties of BMP images
  + Muxer:Optimize output of the Mp4 muxer for streaming on
    Windows too
  + Muxer:Add option to the Mp4 muxer to output fragmented MP4
    files
  + Muxer:Label HEVC video in Mp4 in a way compatible with
    QuickTime on macOS
  + Filter:Fix assembly in Yadif deinterlacer with MSVC++
  + UI:Enable automatic application scaling on Windows for recent
    Qt versions
  + UI:Fix silent mode, automatically confirm dialogs instead of
    choosing the default option
  + Audio:Support WMAPRO audio codec for decoding
  + Audio:Support AAC with signal band replication (SBR) in
    external audio tracks
  + Audio:Fix saving AAC audio tracks with SBR to a file
  + Audio:Improve resilience to false positives when probing
    external audio files for AAC
  + Miscellaneous:Fix crash with OpenGL or DXVA2 video output in 32
    bits Avidemux on Windows (better late than never)
  + Miscellaneous:Fix regressed handling of empty frames in MPEG-4
    and FRAPS video streams
  + Miscellaneous:Numerous other fixes and polish
- Removed avidemux-cmake-permissions.patch, fixed upstream.
* Fri Mar 22 2019 enzokiel@kabelmail.de
- Update to version 2.7.3
  + Vapoursynth is now dynamically loaded to avoid error popup
  + ASF/WMV demuxer fix
  + BMP decoder fix
  + Re-enabled PNG decoder
  + Basic save current state when crashing
  + Misc small improvements
* Sun Mar 17 2019 enzokiel@kabelmail.de
- Update to version 2.7.2
  + Win64 version are now compiled with Visual C++, it should help
    stability wise. You should de-install the previous version
    first
  + New Demuxer:Native AviSynth demuxer (MSVC++ 64 bits Windows
    builds only), 64bits avisynth only !
  + New Demuxer:VapourSynth demuxer to directly load .vpy scripts
    (MSVC++, macOS with Homebrew, custom Linux builds), 64bits
    vapoursynth only on win64!
  + New Installer:Replace NSIS installer with Qt Installer
    Framework for native MSVC++ 64 bits Windows builds
  + New Encoder:Add FFmpeg-based VA-API HW accelerated H.264
    encoder (Intel/Linux)
  + New Encoder:Add FFmpeg-based VA-API HW accelerated HEVC
    encoder (Intel/Linux)
  + FFmpeg:Migrate to the 4.x branch
  + Decoder:As a result of the FFmpeg upgrade, HW accelerated HEVC
    decoding on macOS is now available when supported by the
    hardware
  + Encoder:Fix issues with image quality and skipped frames in
    the MJPEG encoder
  + Demuxer:Fix audio delay calculation in the Mp4 demuxer
  + Demuxer:Fix crash loading large MP4 files with LPCM audio
  + Demuxer:Fix multiple issues in the ASF demuxer, allow to cancel
    indexing
  + Demuxer:Allow to cancel indexing of MKV files
  + Demuxer:Re-enable multiloading for MPEG-TS streams cut in
    chunks of 256, 512 MiB, 1, 2 and 4 GiB in size only
  + Demuxer:Fix MPEG-TS indexer to start a H.264 or HEVC frame with
    the Access Unit Delimiter
  + Muxer:Add Annex B to Annex B video stream filter to deal with
    misplaced frame boundaries
  + Muxer:Add support for setting rotation flag to the MP4 muxer
  + Filter:Add rubber band selector to the "Blacken Borders" filter
  + Filter:Add option to deal with anamorphic display to the
    subtitle filter, fix issues in SRT to SSA converter
  + UI:Autosave session on video close, add session restore feature
  + UI:Add file name extension when saving audio for some audio
    types
  + Audio:Make maximum level in the "Normalize" filter customizable
  + Audio:Improve AAC sampling frequency detection
  + Audio:Add decoding support for multichannel Opus audio
  + Miscellaneous:Fix regression playback stuck after going to the
    previous picture
  + Miscellaneous:Fix regression "Fade to black" reset when
    starting filtered playback close to the end of video
  + Miscellaneous:Fix regression stopping playback rewinds to the
    start of video if seek back to the last displayed picture fails
- Removed avidemux-cpu_armel.patch, avidemux3.desktop and
  config.mak.diff, fixed upstream.
- Fixed avidemux-linking.patch, avidemux-package_version.patch and
  avidemux-x265_plugins.patch.
- Added avidemux-desktop-file.patch to fix wrong category.
* Tue Jun  5 2018 enzokiel@kabelmail.de
- Update to version 2.7.1
  + Encoder:Add LibVA based HW accelerated H.264 encoder
    (Intel/Linux)
  + Decoder:Fix last frames of video not retrieved from decoder
  + Decoder:Implement hardware accelerated decoding of H.264 on
    macOS
  + Decoder:Fix keyframe-based navigation in field-encoded MPEG-2
    video
  + Demuxer:Fix crash in the Matroska demuxer with high bitrate
    audio
  + Demuxer:Fix too short duration reported for MKV and MP4 with
    B-frames
  + Demuxer:Fix PTS delay calculation in the Matroska demuxer
  + Demuxer:Fix audio delay ignored by the Mp4 demuxer
  + Muxer:Improve resilience of FFmpeg based muxers against decode
    timestamps irregularities
  + Muxer:Allow to force display aspect ratio in the configuration
    of the MP4 muxer
  + Muxer:Fix crash in the AVI muxer on switch to OpenDML
  + Images:Add PNG export, fix wrong colors with some colorspaces
  + Images:Add feature to export selection as JPEG images
  + Editor:Fix AVI with H.264 / HEVC without B-frames being not
    seekable
  + Editor:Make AVI with H.264 / HEVC containing B-frames seekable
    by decoding the entire video
  + New Filter:Still Image: generate video of specified duration out
    of a single image
  + Filter:Make eq2 video filter partializable
  + Filter:Implement fade-in / fade-out transition for "Add logo"
  + UI:Display selection duration in the UI, move filter preview
    toggle to the toolbar
  + UI:Warn right away if an edit would result in cuts being not on
    keyframes
  + UI:Improve time chooser dialog
  + Audio:Add Opus encoder
  + Audio:Allow LPCM in FFmpeg-based muxers
  + Audio:Show duration for external audio tracks
  + Miscellaneous:Improved overall polish and stability
- Removed avidemux-glibc-2.27.patch, fixed upstream.
- Removed all qt4 stuff.
- Added avidemux-backport_Fix_threads_setup.patch.
* Sat Apr  7 2018 enzokiel@kabelmail.de
- Added avidemux-glibc-2.27.patch to Fix compilation with
  glibc >= 2.27.
* Mon Aug 14 2017 joerg.lorenzen@ki.tng.de
- Update to version 2.7.0
  + Core:FFmpeg switched to the 3.3.x branch
  + Editing:Fixed frame computation bug that led to bad cutting
    (euma)
  + i18n:Korean translation (sheppaul)
  + win32:Put log files into the local folder (achim71)
  + Jobs:Fix name of the executable search
  + UI:Steplessly zoom paused video when the window is resized
    (euma)
  + UI:Added Ctrl+Shift+C shortcut to copy the current PTS to
    clipboard (euma)
  + Filter:eq2: UI improvements (euma)
  + Decoding:Fix VP9 decoding
  + Filter:Using rubber bands for crop too (me+euma)
  + Build:Redone packaging on macOS
  + Decoding:HEVC decoding via DXVA2 blacklisted on win32, active
    on win64
  + New Filter:ADM ivtc
  + Audio:Distinguish between AC3 and EAC3 when importing
* Sun Apr 30 2017 joerg.lorenzen@ki.tng.de
- Update to version 2.6.20
  + Audio : AAC in mpegTS fix
  + Audio : external AAC import fix
  + MKV : try to better guess original timestamp
  + i18n : Russian and German translation update
    (TotalCaesar659 / euma)
  + UI : Filter UI fix
* Thu Mar 30 2017 joerg.lorenzen@ki.tng.de
- Update to version 2.6.19
  + Filter : All filters with preview have better navigation
    dialogs
  + Filter : Delogo filter UI redone
  + Filter : Fixed changeFps/resampleFps seeking
  + TS/Demux : HEVC support improved
  + Flv/Demux : Support large files (rcdrone)
  + Audio : Allow EAC3 as external audio track
  + UI : General usability cleanup (euma)
  + UI : Allow using the last read folder as default save folder
    (euma)
  + UI : 2 pass encoding dialog cleanup (euma)
  + UI : Dynamically enable/disable menu (euma)
  + UI : Customizable keyboard shortcut (euma)
  + UI : Allow reverting page up/down (euma)
  + Codec : Better support for 10bits
  + i18n : Russian translation updated (TotalCaesar659)
  + i18n : Greek translation updated (nikoss)
  + i18n : General cleanup (euma)
  + Updated ffmpeg libs to 3.0.7
* Sun Jan  8 2017 joerg.lorenzen@ki.tng.de
- Update to version 2.6.18
  * Fixed slider in preview mode
- Version 2.6.17
  * Allow EAC3 in mp4 and mp4v2 (fiftyplus/euma)
  * Fix behaviour of preview window when video size is ~ screen
    size
* Fri Jan  6 2017 joerg.lorenzen@ki.tng.de
- Enabled support for fdk-aac.
* Wed Jan  4 2017 joerg.lorenzen@ki.tng.de
- Update to version 2.6.16
  + Build : Avidemux can be built with visual c++ 2015 (losing
    some ASM)
  + OsX : Initialize fontconfig so that subtitling works
  + Core : Update ffmpeg to 3.0.5
  + i18n : Updated fr and ru translations
    (jean Elchinger/totalcaesar659)
  + Build : Improved build scripts (euma)
  + x265 : Enforce complicancy with most devices
  + vaapi : Add resizer
  + UI : Redone UI, revamped contrast filter
  + Qt : Dont use too much CPU on playback when there is no audio
    track
  + Qt : Reenabled nvenc + Fixed keyframe detection
  + Qt : Fixed a crash when encoding starts very slowly (x265)
  + Build : Allow use of system libass, liba52,libmad (euma)
* Mon Nov 21 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.6.15
  + Hw Accel : Fixed nvEnc and added simple nvEnc-HEVC
    (windows/linux)
  + Hw Accel : Added support for HEVC/VC1 with libVA (linux)
  + Hw Accel : Experimental Dxva2 video decoder + Dxva2/D3D display
    engine (windows)
  + Demux : Mpeg TS, fix non multiple of 16 file management (euma)
  + Audio/win32 : Fixed CPU consumption when playing audio
  + Editor : Fixed copy /paste /delete /undo (euma)
  + Editor : A *lot* of seeking bugs fixed (euma)
  + Editor : A *lot* of marker management bugs fixed (euma)
  + Audio : Added FDK-AAC as encoder
  + x26* : Added a "None" preset
  + x265 : Fixed 2 pass encoding on windows
  + i18n : Qt4 vs Qt5 language fix (D. Amm)
  + i18n : German translation updated (euma)
  + UI : Added reload default settings (euma)
  + UI : Allow minimizing to tray while encoding (euma)
  + OSX : Update to Sierra
* Wed Sep 21 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.6.14
  i18n:
  + A lot more is now translatable (D. Amm)
  + Hungarian translation (rezso)
  + German translation update (euma)
  + French translation update
  + PT/BR translation partially fixed
  + Dannish translation update (scootergrisen)
  Platforms:
  + Qtx : Automatically check if a new version is available once a
    day
  + WIN32 : Reverted to MXE cross compiler, XP now works again
  + OSX : Fixed the packager, it should work every time now (no
    more borked dmg)
  Application:
  + Decoding : Deal with corrupted stream in a nicer way (H264/TS)
  + Decoding : Enable lagarith
  + Decoding : Support for flac through libavcodec
  + VDPAU : Try harder to release resources at exit
  + Demuxer : Image loader improved and cleaned up, more jpeg
    formats are supported
  + Editor : Try to deal better with corrupted audio in copy mode
  + TS : Add support for new EAC3 identifier such as the ones used
    by numericable / DVB-T
  + Encoder : Fix most of the libavcodec based encoders
* Sat Aug 20 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.6.13
  + [OsX] Toolchain updated
  + [Win64] Toolchain updated
  + [Linux] AppImage (universal linux64 binaries)
  + [Core] Update to libav* 3.0.2
  + [Edit] Improved copy mode for h264/h265 video
  + [Audio] AAC/ADTS import/export
  + [Filter] new video filter : ivtcDupeRemover to remove duplicate
    after 3:2 pulldown
  + [Qt] Revamped refresh screen
  + [Filters] ASS/SSA fixes
  + [Filters] Improved logo filter with alpha channel
  + [Win32] Development files included in installer
  + [Filter] ShaderLoader, load your openGL shaders as filters
  + [Linux] Compatibility with newer gcc
  + [Filter] Partial filter available only for one in/one out video
    filters
  + [UI] Add go fwd/go backward 60 sec buttons
  + [i18n] Translations updated
- Removed avidemux-find-lrelease-qt5.patch, fixed upstream
- Fixed all patches
- Disabled ix86 for SLES 11 because build currently fails
  (perhaps compiler too old?)
* Tue Mar  8 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.6.12
  + [H264] Fixed crash when saving h264 annexB in avi (Brundle)
  + [Vdpau] Fixed VDPAU resize and deinterlace when height is padded
  + [Mkv] Faster loading of VP9 and h265
  + [MP4] Supports more flavors of H265
  + [i18n] Spanish translation update by ringmaster
  + [Edit] Another frame seeking bug fixed, happened rarely
  + [All] Slightly better crash handler
  + [FFmpeg]Update to 2.7.6
  + [Muxer] Basic webm support
  + [Jobs] Fixed right click menus with qt5
* Fri Feb  5 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.6.11
  + Better support for H265
  + Fix off-by-one keyframe cutting
  + Basic support for Opus
  + Try to cope better with decoding error
  + Extract keyframes from non Mpeg video in mkv
  + Cap refresh rate for large video or slow machines
  + Fix nv12 to yv12 mmx code
- Update internal ffmpeg to version 2.8.6
- Build against qt5 for openSUSE > 13.2 and Leap 42.1
- Don't build gtk frontend because build currently fails and it
  hasn't been maintained for a long time (information from
  developer)
* Mon Jan 18 2016 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 2.8.5
* Wed Dec 23 2015 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 2.8.4
* Sat Dec  5 2015 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 2.8.3
* Fri Nov 20 2015 olaf@aepfle.de
- Set group permissions for included ffmpeg libs
* Fri Oct 16 2015 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 2.8.1
* Wed Sep  9 2015 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 2.8
* Mon Jul 20 2015 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 2.7.2
* Sat Jul 11 2015 joerg.lorenzen@ki.tng.de
- Update to version 2.6.10
  * Re-added translations
  * Re-added avsproxy
  * Fixed multi passes with x264 when file has non ascii chars
  * Added experimental Qt5 build for mac
  * Fixed a bug with filler frames (fraps)
- update internal ffmpeg to version 2.7.1
- Version 2.6.9
  * x265 support by KoolAidMan.
  * Qt4 and Qt5 support.
  * Compatibility with newer VAAPI.
  * Updated ffmpeg libraries.
  * Simple support for nvenc (linux).
  * Better compatibility with Dash file, Flv.
  * AvsProxy improvements (hinterwaeldler).
  * Misc fixes (asjchult).
  * Plenty of bugfixes and new bugs.
  * Win32 and Win64 builds are now using winbuilds.org, Xp no
    longer supported.
* Sat May  2 2015 joerg.lorenzen@ki.tng.de
- fixed build for openSUSE = 11.4
* Thu Feb 26 2015 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.12
* Tue Dec 23 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.11
- removed workaround for build on arm armv6l/armv6hl, the problem
  is caused by additional RaspberryPi repository and should be
  fixed there
* Sat Dec 13 2014 joerg.lorenzen@ki.tng.de
- removed some unneeded dependencies to enable build on armv6l/armv6hl
* Sat Nov  8 2014 joerg.lorenzen@ki.tng.de
- added patch and dependencies to enable build on ARM CPU
- removed some unneeded dependencies
* Wed Nov  5 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.10
* Fri Oct 17 2014 joerg.lorenzen@ki.tng.de
- changed BuildRequires to pkgconfig where possible
- enable build for SLES, unfortunately without frontends qt and gtk
  because SLES doesn't provide gtk3 and qt >= 4.7
* Fri Oct 10 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.9
* Fri Aug 22 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.8
* Tue Jun 24 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.7
* Fri Mar 14 2014 joerg.lorenzen@ki.tng.de
- Update to version 2.6.8
  * Image/export: Proper initialization of Qz for jpeg export
  * UI : Add an override menu to force language
  * tinypy : Add support for os.environ
  * x264 : Improved settings (tobias)
  * Win32 : Fix crash when having an audio problem
  * Win32 : Re-add mp4v2 to installer files
  * Audio/FAAC : Fix channel mapping when source is mono
  * Audio/AMR : Re-enabled AMR
  * Audio/lavc : Fixed encoding for codec not supporting planar (MP2)
  * Audio : Fixed importing MP2 audio detected as MP3
  * Editor : Fix deleting chunks of the video leading to seek errors
  * Editor : Initial copy/paste support
  * Editor/audio: Fix issue when source has more than 4 tracks
  * Editor : Better detection of double fps input files
  * TS/Demux : Brute force eac3 probe
  * TS/Demux : Better initialization, avoid dropping audio
  * MP4/Demux : Fix management of PCM audio
  * Mkv/Demux : Proper re-indexing for mpeg2 in mkv
  * Mp4v2/Mux : Add fast start mode back
  * OpenSolaris : Some fixes by pfelecan
  * Subtitles : Update libass + very simple srt2ssa converter
  * OsX : Enables more optional codecs...
  * avsfilte : Performance Improvements (fahr)
* Wed Mar 12 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.6
* Sat Feb  1 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.5
* Mon Dec  9 2013 joerg.lorenzen@ki.tng.de
- Update to version 2.6.7
  * [MKV] Fix seeking in h264
  * [TS/H264] Split on NALU boundaries, it was off by one byte
  * [TS/AAC] Add support for AAC/LC/SBR
  * [MOV/MP4] Correct management of PCM/8Bits audio track
  * [Images] Fixed import of bmp and jpg
  * [Build] Support for newer cmake (ajschult)
  * [Build] Better RPM generation (mit)
  * [Auto/PSP] Fixed scripts (LJ)
* Sat Nov  2 2013 joerg.lorenzen@ki.tng.de
- changes in spec file to enable build for openSUSE 11.4 and 12.1
* Wed Oct 30 2013 joerg.lorenzen@ki.tng.de
- Initial package, version 2.6.6
